Class: ThoughtSpotPublicRestApi::UpdateMetadataHeaderRequest

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/thought_spot_public_rest_api/models/update_metadata_header_request.rb

Overview

UpdateMetadataHeaderRequest Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(headers_update:, org_identifier: SKIP, additional_properties: nil) ⇒ UpdateMetadataHeaderRequest

Returns a new instance of UpdateMetadataHeaderRequest.



40
41
42
43
44
45
46
47
48
# File 'lib/thought_spot_public_rest_api/models/update_metadata_header_request.rb', line 40

def initialize(headers_update:, org_identifier: SKIP,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @headers_update = headers_update
  @org_identifier = org_identifier unless org_identifier == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#headers_updateArray[HeaderUpdateInput]

List of header objects to update.

Returns:



14
15
16
# File 'lib/thought_spot_public_rest_api/models/update_metadata_header_request.rb', line 14

def headers_update
  @headers_update
end

#org_identifierString

Unique ID or name of the organization.

Returns:

  • (String)


18
19
20
# File 'lib/thought_spot_public_rest_api/models/update_metadata_header_request.rb', line 18

def org_identifier
  @org_identifier
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
# File 'lib/thought_spot_public_rest_api/models/update_metadata_header_request.rb', line 51

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  # Parameter is an array, so we need to iterate through it
  headers_update = nil
  unless hash['headers_update'].nil?
    headers_update = []
    hash['headers_update'].each do |structure|
      headers_update << (HeaderUpdateInput.from_hash(structure) if structure)
    end
  end

  headers_update = nil unless hash.key?('headers_update')
  org_identifier =
    hash.key?('org_identifier') ? hash['org_identifier'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  UpdateMetadataHeaderRequest.new(headers_update: headers_update,
                                  org_identifier: org_identifier,
                                  additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



21
22
23
24
25
26
# File 'lib/thought_spot_public_rest_api/models/update_metadata_header_request.rb', line 21

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['headers_update'] = 'headers_update'
  @_hash['org_identifier'] = 'org_identifier'
  @_hash
end

.nullablesObject

An array for nullable fields



36
37
38
# File 'lib/thought_spot_public_rest_api/models/update_metadata_header_request.rb', line 36

def self.nullables
  []
end

.optionalsObject

An array for optional fields



29
30
31
32
33
# File 'lib/thought_spot_public_rest_api/models/update_metadata_header_request.rb', line 29

def self.optionals
  %w[
    org_identifier
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



89
90
91
92
93
# File 'lib/thought_spot_public_rest_api/models/update_metadata_header_request.rb', line 89

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} headers_update: #{@headers_update.inspect}, org_identifier:"\
  " #{@org_identifier.inspect}, additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



82
83
84
85
86
# File 'lib/thought_spot_public_rest_api/models/update_metadata_header_request.rb', line 82

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} headers_update: #{@headers_update}, org_identifier: #{@org_identifier},"\
  " additional_properties: #{@additional_properties}>"
end